#!/bin/ksh

#
#  capodbc.ksh by Robb Oliver
#
#  This script captures various info about a users
#  Unix system and product installation and outputs
#  it to a text file that can be e-mailed to a rep.
#
#  2003.05.09 : Changed extension to ksh
#  2003.05.09 : Changed Connect ODBC to Connect for ODBC
#  2003.05.14 : Added checksum of files
#  2003.06.13 : Redirected stderr to file also
#  2003.08.15 : Tared and compressed output
#  2003.08.18 : Added Locale information
#  2003.09.05 : Added ldd information for example/demo
#  2004.03.09 : Added ivtestlib output for drivers
#

# Get current working directory
CE_PWD=`pwd`

# output file that will be created
CE_OUTFILE="$CE_PWD/capodbc.txt"

# tar file that will be created
CE_TARFILE="$CE_PWD/capodbc.txt.tar"

# find command
CE_FIND=`which find`

# default prefix
CE_PREFIX="iv"

# command to tar
CE_TAR_CMD="tar -cvf"

# command to compress
CE_COMPRESS_CMD="compress -f"

# the compressed tar name
CE_COMPRESSED_TAR="$CE_TARFILE.Z"

# os names
CE_AIX="AIX"
CE_SOLARIS="SunOS"
CE_HP="HP-UX"
CE_LINUX="Linux"

# Default LDD command
CE_LDD="#"

# Print info about the file we are about to create
echo "\nCreating file $CE_OUTFILE...\c"
echo "Original full path of file: $CE_OUTFILE\n" > $CE_OUTFILE

# Record a time stamp
echo "Timestamp : `date`\n" >> $CE_OUTFILE 2>&1

# Get infor about the user's system and version
echo "*** System information\n" >> $CE_OUTFILE 2>&1 
echo "uname   : `uname -a`" >> $CE_OUTFILE 2>&1
echo "uptime  :`uptime`" >> $CE_OUTFILE 2>&1

# Get information about the current user
echo "\n*** User information\n" >> $CE_OUTFILE 2>&1
CE_USERID=`whoami`
CE_GROUPS=`groups $CE_USERID`

echo "User    : $CE_USERID" >> $CE_OUTFILE 2>&1
echo "Groups  : $CE_GROUPS" >> $CE_OUTFILE  2>&1
echo "umask   : `umask`" >> $CE_OUTFILE 2>&1

# output the customers environment
echo "\n*** Environment (using env command):\n" >> $CE_OUTFILE 2>&1
env >> $CE_OUTFILE 2>&1

# locale information
echo "\n*** Locale information\n" >> $CE_OUTFILE 2>&1

echo "Current locale settings :\n" >> $CE_OUTFILE 2>&1
locale >> $CE_OUTFILE 2>&1

echo "\nPossible locale settings :\n" >> $CE_OUTFILE 2>&1
locale -a >> $CE_OUTFILE 2>&1

# Now get ODBC info
# Check to make sure ODBCINI is defined and then add that
# to the output
echo "\n*** Current ODBCINI\n" >> $CE_OUTFILE 2>&1
echo "ODBCINI : $ODBCINI\n" >> $CE_OUTFILE 2>&1

if [[ -n $ODBCINI && -f $ODBCINI ]] ; then

	cat $ODBCINI >> $CE_OUTFILE 2>&1
	
	# Also get the Install dir from ODBCINI
	CE_INSTALLDIR=`grep "InstallDir" $ODBCINI | awk -F= '{print $2}'`

else

	# include a little error to let them know the ODBCINI wasn't set
	echo "\n\nERROR: The ODBCINI environment variable was not properly set."
	echo "       Information about the Connect for ODBC installation will not be"
	echo "       included in the output file.\n"

	echo "No ODBCINI found (ODBCINI=$ODBCINI)" >> $CE_OUTFILE 2>&1
	CE_INSTALLDIR=""
fi

# Get ldd information based on example and os
# Also get the versions of the drivers
if [[ -n $CE_INSTALLDIR ]] ; then

	CE_OS=`uname -s`
	CE_EXAMPLE="$CE_INSTALLDIR/example/example"
	CE_DEMO="$CE_INSTALLDIR/demo/demoodbc"
	CE_IVTESTLIB="$CE_INSTALLDIR/bin/ivtestlib"

	if [[ $CE_OS = $CE_AIX ]] ; then

		CE_LDD=`which ldd`
		CE_LIB_EXT="so"

	elif [[ $CE_OS = $CE_HP ]] ; then

		CE_LDD=`which ldd`
		CE_LIB_EXT="sl"

	elif [[ $CE_OS = $CE_SOLARIS ]] ; then

		CE_LDD=`which ldd`
		CE_LIB_EXT="so"

	elif [[ $CE_OS = $CE_LINUX ]] ; then

		CE_LDD=`which ldd`
		CE_LIB_EXT="so"
	fi

	# if ldd actually exists use it
	if [[ -f $CE_LDD && -f $CE_EXAMPLE ]] ; then

		echo "\n*** Output of $CE_LDD $CE_EXAMPLE\n" >> $CE_OUTFILE 2>&1
		$CE_LDD $CE_EXAMPLE >> $CE_OUTFILE 2>&1
	fi

	if [[ -f $CE_LDD && -f $CE_DEMO ]] ; then

		echo "\n*** Output of $CE_LDD $CE_DEMO\n" >> $CE_OUTFILE 2>&1
		$CE_LDD $CE_DEMO >> $CE_OUTFILE 2>&1
	fi	

	if [[ -f $CE_IVTESTLIB ]] ; then

		echo "\n*** DataDirect driver versions (ivtestlib)\n" >> $CE_OUTFILE 2>&1
		$CE_FIND $CE_INSTALLDIR/lib -name $CE_PREFIX*.$CE_LIB_EXT -exec $CE_IVTESTLIB {} \; >> $CE_OUTFILE 2>&1
	fi
fi

# Capture the install dir if we got it from ODBCINI
echo "\n*** Connect ODBC Directory structure and files\n" >> $CE_OUTFILE 2>&1
echo "InstallDir : $CE_INSTALLDIR\n" >> $CE_OUTFILE 2>&1
if [[ -n $CE_INSTALLDIR ]] ; then

	ls -laR $CE_INSTALLDIR/* >> $CE_OUTFILE 2>&1

	# Get the checksum of the files
	echo "\n*** Connect for ODBC checksum values\n" >> $CE_OUTFILE 2>&1
	cksum `find $CE_INSTALLDIR -type b -o -type c -o -type f` >> $CE_OUTFILE 2>&1
else

	echo "Unable to determine InstallDir" >> $CE_OUTFILE 2>&1
fi

# Print that we are done creating the file
echo "done.\n"
echo "\n*** End of $CE_OUTFILE" >> $CE_OUTFILE 2>&1

# tar it up
echo "TARing output...\c"
$CE_TAR_CMD $CE_TARFILE $CE_OUTFILE > /dev/null
echo "done.\n"

# compress it
echo "Compressing output...\c"
$CE_COMPRESS_CMD $CE_TARFILE
echo "done.\n"

echo "Send $CE_COMPRESSED_TAR to DataDirect support.\n"

